@@ -81,7 +81,7 @@ class JSFacter(Facter):
         self.review.facts['page.js']['value'].add(url)
         self.review.data['page.js'].add((url, response))
 
-        if response.text is not None:
+        if response.text:
             size_js = len(response.text) / 1024.0
             size_gzip = len(self.to_gzip(response.text)) / 1024.0
         else:
